@@ -1,4 +1,4 @@
-// $Id: Colors.cc 3491 2009-09-04 21:40:05Z flaterco $
+// $Id: Colors.cc 4406 2012-03-04 14:26:16Z flaterco $
 
 /*  Colors  Manage XTide colors without X.
 
@@ -27,6 +27,45 @@ constString Colors::colorarg[numColors] = {
 };
 
 
+#ifndef SCNx8
+#ifdef USE_PRAGMA_MESSAGE
+#pragma message("WARNING:  SCNx8 is not defined.  Using workaround.")
+#else
+#warning SCNx8 is not defined.  Using workaround.
+#endif
+
+// 2011-11-27  Visual C++ 2010 has no scan format that works with uint8_t.
+// "hhx" and "x" both write zeros into subsequent bytes, corrupting memory.
+
+#define SCNx8 "x"
+
+static int scanRedirect (const char *str,
+			 const char *format,
+			 uint8_t *x_out) {
+  unsigned x;
+  int rtn = sscanf (str, format, &x);
+  *x_out = x;
+  return rtn;
+}
+
+static int scanRedirect (const char *str,
+			 const char *format,
+			 uint8_t *r_out,
+			 uint8_t *g_out,
+			 uint8_t *b_out) {
+  unsigned r, g, b;
+  int rtn = sscanf (str, format, &r, &g, &b);
+  *r_out = r;
+  *g_out = g;
+  *b_out = b;
+  return rtn;
+}
+
+#define sscanf scanRedirect
+
+#endif
+
+
 const bool Colors::parseColor (const Dstr &colorName,
 			       uint8_t &r,
 			       uint8_t &g,
@@ -36,6 +75,10 @@ const bool Colors::parseColor (const Dstr &colorName,
   r = g = b = 0;
   constString fmt1 = "rgb:%" SCNx8 "/%" SCNx8 "/%" SCNx8;
 
+  // When SCNx8 *is* defined, we can get a lot of:
+  // warning: ISO C++ does not support the 'hh' gnu_scanf length modifier
+  quashWarning(-Wformat)
+
   if (sscanf (colorName.aschar(), fmt1, &r, &g, &b) != 3) {
 
     r = g = b = 0;
@@ -69,6 +112,7 @@ const bool Colors::parseColor (const Dstr &colorName,
       temp[1] = colorName[6];
       sscanf (temp, fmt2, &b);
 
+  unquashWarning
     } else {
       for (unsigned rr=0; rgbtxt[rr].name; ++rr)
 	if (dstrcasecmp (colorName, rgbtxt[rr].name) == 0) {
