@@ -1,4 +1,4 @@
-// $Id: Graph.cc 3491 2009-09-04 21:40:05Z flaterco $
+// $Id: Graph.cc 4303 2012-02-14 00:59:27Z flaterco $
 
 /*  Graph  Abstract superclass for all graphs.
 
@@ -32,10 +32,6 @@
 // range, that slack is gone.
 const double Graph::vertGraphMargin (0.1);
 
-// In drawing of line graphs, slope at which to abandon the thick line
-// drawing algorithm.
-static const double slopeLimit (5.0);
-
 
 Graph::Graph (unsigned xSize, unsigned ySize, GraphStyle style):
   _style(style),
@@ -65,22 +61,22 @@ static void findNextSunEvent (TideEventsIterator &it,
 }
 
 
-const double Graph::linterp (double lo, double hi, double saturation) const {
-  return lo + saturation * (hi - lo);
+const double Graph::linterp (double lo, double hi, double opacity) const {
+  return lo + opacity * (hi - lo);
 }
 
 
 const unsigned char Graph::linterp (unsigned char lo,
 				    unsigned char hi,
-				    double saturation) const {
-  return (unsigned char) linterp ((double)lo, (double)hi, saturation);
+				    double opacity) const {
+  return (unsigned char) linterp ((double)lo, (double)hi, opacity);
 }
 
 
 const unsigned short Graph::linterp (unsigned short lo,
 				     unsigned short hi,
-				     double saturation) const {
-  return (unsigned short) linterp ((double)lo, (double)hi, saturation);
+				     double opacity) const {
+  return (unsigned short) linterp ((double)lo, (double)hi, opacity);
 }
 
 
@@ -107,10 +103,10 @@ void Graph::checkDepth (double ymax,
     // Leave room for 3 lines of text at top, 3 lines of text plus
     // tick marks at bottom.
     if (ytide - fontHeight()/2 - depthLineVerticalMargin() <=
-                                      (fontHeight()+fontVerticalMargin()) * 3)
+                                      fontHeight() * 3)
       break;
     if (ytide + fontHeight()/2 + depthLineVerticalMargin() >=
-             _ySize - (fontHeight()+fontVerticalMargin()) * 3 - hourTickLen())
+	_ySize - fontHeight() * 3 - hourTickLen() - hourTickVerticalMargin())
       continue;
     maxDepth_out = depth;
     if (depth < minDepth_out) // In case one loop is never executed.
@@ -121,10 +117,10 @@ void Graph::checkDepth (double ymax,
     // Leave room for 3 lines of text at top, 3 lines of text plus
     // tick marks at bottom.
     if (ytide - fontHeight()/2 - depthLineVerticalMargin() <=
-                                      (fontHeight()+fontVerticalMargin()) * 3)
+                                      fontHeight() * 3)
       continue;
     if (ytide + fontHeight()/2 + depthLineVerticalMargin() >=
-             _ySize - (fontHeight()+fontVerticalMargin()) * 3 - hourTickLen())
+	_ySize - fontHeight() * 3 - hourTickLen() - hourTickVerticalMargin())
       break;
     minDepth_out = depth;
     if (depth > maxDepth_out) // In case one loop is never executed.
@@ -142,54 +138,10 @@ void Graph::drawDepth (double ymax,
 		       int minDepth,
 		       int maxDepth) {
   for (int depth=minDepth; depth<=maxDepth; depth+=lineStep)
-    drawHorizontalLine (labelWidth,
-                        _xSize-1,
-                        xlate(0.1*depth),
-                        Colors::foreground);
-}
-
-
-void Graph::drawFunkyLine (double prevytide,
-                           double ytide,
-                           double nextytide,
-                           int x,
-                           Colors::Colorchoice c) {
-  double dy, yleft, yright;
-  double slw (Global::settings["lw"].d);
-
-  // The fix for line slope breaks down when the slope gets nasty, so
-  // switch to a more conservative strategy when that happens.  Line
-  // width becomes 1 no matter what.
-
-#define dohalfline(yy) {                                          \
-  double lw;                                                      \
-  if (fabs(dy) < slopeLimit)                                      \
-    lw = (1.0 + (M_SQRT2 - 1.0) * fabs(dy)) * slw / 2.0;          \
-  else                                                            \
-    lw = (fabs(dy) + slw) / 2.0;                                  \
-  if (dy < 0.0)                                                   \
-    lw = -lw;                                                     \
-  yy = ytide - lw;                                                \
-}
-
-  dy = ytide - prevytide;
-  dohalfline (yleft);
-  dy = ytide - nextytide;
-  dohalfline (yright);
-
-  // Fix degenerate cases.
-  if (ytide > yleft && ytide > yright) {
-    if (yleft > yright)
-      yleft = ytide + slw / 2.0;
-    else
-      yright = ytide + slw / 2.0;
-  } else if (ytide < yleft && ytide < yright) {
-    if (yleft < yright)
-      yleft = ytide - slw / 2.0;
-    else
-      yright = ytide - slw / 2.0;
-  }
-  drawVerticalLine (x, yleft, yright, c);
+    drawHorizontalLinePxSy (labelWidth,
+			    _xSize-1,
+			    xlate(0.1*depth),
+			    Colors::foreground);
 }
 
 
@@ -200,48 +152,46 @@ void Graph::clearGraph (Timestamp startTime,
                         TideEventsOrganizer &organizer) {
   assert (station);
 
-  // True if event mask is set to suppress sunrises *or* sunsets
-  bool ns (Global::settings["em"].s.contains("s"));
+  // Shortcut if event mask is set to suppress sunrises or sunsets.
+  if (Global::settings["em"].s.contains("s")) {
+    drawBoxS (0, _xSize, 0, _ySize, Colors::daytime);
+    return;
+  }
 
   // Clear the graph by laying down a background of days and nights.
   bool sunIsUp = true;
-  if (!(station->coordinates.isNull()) && !ns)
+  if (!(station->coordinates.isNull()))
     sunIsUp = Skycal::sunIsUp (startTime, station->coordinates);
 
   Timestamp loopTime (startTime);
   Timestamp nextSunEventTime;
   TideEventsIterator it (organizer.begin());
-  findNextSunEvent (it, organizer, loopTime, endTime, nextSunEventTime);
-  for (unsigned x=0; x<_xSize; ++x, loopTime += increment) {
-    if (loopTime >= nextSunEventTime && !ns) {
-      findNextSunEvent (it, organizer, loopTime, endTime, nextSunEventTime);
-      assert (loopTime < nextSunEventTime);
-      if (it != organizer.end()) {
-        switch (it->second.eventType) {
-        case TideEvent::sunrise:
-          sunIsUp = false;
-          break;
-        case TideEvent::sunset:
-          sunIsUp = true;
-          break;
-        default:
-          assert (false);
-	}
-      } else
-        sunIsUp = !sunIsUp;
-    }
+  while (loopTime < endTime) {
+    findNextSunEvent (it, organizer, loopTime, endTime, nextSunEventTime);
+    assert (loopTime < nextSunEventTime);
+    if (it != organizer.end()) {
+      switch (it->second.eventType) {
+      case TideEvent::sunrise:
+	sunIsUp = false;
+        break;
+      case TideEvent::sunset:
+	sunIsUp = true;
+	break;
+      default:
+	assert (false);
+      }
+    } else
+      sunIsUp = !sunIsUp;
+
     Colors::Colorchoice c = (sunIsUp ? Colors::daytime : Colors::nighttime);
-    drawVerticalLine (x, 0, _ySize-1, c);
+    double x1 = (loopTime-startTime)/increment;
+    double x2 = std::min ((double)_xSize, (nextSunEventTime-startTime)/increment);
+    drawBoxS (x1, x2, 0, _ySize, c);
+    loopTime = nextSunEventTime;
   }
 }
 
 
-void Graph::drawX (int x, double y) {
-  drawVerticalLine   (x, y-4, y+4, Colors::foreground);
-  drawHorizontalLine (x-4, x+4, y, Colors::foreground);
-}
-
-
 static void makeDepthLabel (int depth,
 			    unsigned lineStep,
 			    const Dstr &unitsDesc,
@@ -283,7 +233,7 @@ void Graph::figureLabels (double ymax,
   {
     unsigned prevStep (lineStep_out), prevMult (10);
     while (yzulu - xlate(0.1*lineStep_out) <
-	   fontHeight() + fontVerticalMargin()) {
+	   oughtHeight() + oughtVerticalMargin()) {
       switch (prevMult) {
       case 10:
 	prevMult = 2;
@@ -392,9 +342,6 @@ void Graph::drawTides (Station *station,
   figureLabels (ymax, ymin, valmax, valmin, unitsDesc, lineStep, labelWidth,
 		labelRight, minDepth, maxDepth);
 
-  char tl (Global::settings["tl"].c);
-  char nf (Global::settings["nf"].c);
-  char el (Global::settings["el"].c);
   Interval increment (std::max ((interval_rep_t)1,
            Global::intervalround (Global::aspectMagicNumber /
                                   (double)_ySize /
@@ -486,62 +433,41 @@ void Graph::drawTides (Station *station,
 
   clearGraph (startTime, endTime, increment, station, organizer);
 
-  // Draw depth lines now?
+  // Draw depth lines sooner?
+  const char tl (Global::settings["tl"].c);
   if (tl == 'n')
     drawDepth (ymax, ymin, valmax, valmin, lineStep, labelWidth, minDepth,
 	       maxDepth);
 
-  // Prepare to draw the actual tides.
-  double prevval, prevytide;
-  double val (station->predictTideLevel(startTime-increment).val());
-  double ytide = xlate(val);
-  const double yzulu (xlate(0));
-  double nextval (station->predictTideLevel(startTime).val());
-  double nextytide (xlate (nextval));
-  Timestamp loopt;
-  int x;
-  startPixelCache();
-
-  // loopt is actually 1 step ahead of x.
-  for (x=0, loopt=startTime+increment;
-       x<(int)_xSize;
-       ++x, loopt += increment) {
-
-    prevval = val;
-    prevytide = ytide;
-    val = nextval;
-    ytide = nextytide;
-    nextval = station->predictTideLevel(loopt).val();
-    nextytide = xlate(nextval);
-
-    // Coloration is determined from the predicted heights, not from
-    // the eventTypes of surrounding tide events.  Ideally the two
-    // would never disagree, but for pathological sub stations they
-    // can.
-    if (station->isCurrent) {
-      Colors::Colorchoice c = (val > 0.0 ? Colors::flood : Colors::ebb);
-      if (nf == 'n')
-        drawVerticalLine (x, yzulu, ytide, c);
-      else
-        drawFunkyLine (prevytide, ytide, nextytide, x, c);
-    } else {
-      Colors::Colorchoice c = (prevval < val ? Colors::flood : Colors::ebb);
-      if (nf == 'n')
-        drawVerticalLine (x, _ySize, ytide, c);
-      else
-        drawFunkyLine (prevytide, ytide, nextytide, x, c);
-    }
-
+  // Draw the actual tides.
+  {
+    SafeVector<double> val(_xSize+3), y(_xSize+3);
 #ifdef blendingTest
-    NullablePredictionValue firstYear, secondYear;
-    station->tideLevelBlendValues (loopt-increment, firstYear, secondYear);
-    if (!firstYear.isNull())
-      setPixel (x, (int)xlate(firstYear.val()), Colors::mark);
-    if (!secondYear.isNull())
-      setPixel (x, (int)xlate(secondYear.val()), Colors::msl);
+    SafeVector<BlendBlob> blendBlobs(_xSize+3);
 #endif
+    unsigned x;
+    Timestamp loopt;
+    for (x=0, loopt=startTime-increment;
+	 x < _xSize+3; ++x, loopt += increment) {
+      val[x] = station->predictTideLevel(loopt).val();
+      y[x]   = xlate(val[x]);
+#ifdef blendingTest
+      NullablePredictionValue firstYear, secondYear;
+      station->tideLevelBlendValues (loopt, firstYear, secondYear);
+      assert (firstYear.isNull() == secondYear.isNull());
+      blendBlobs[x].isNull = firstYear.isNull();
+      if (!blendBlobs[x].isNull) {
+        blendBlobs[x].firsty = xlate(firstYear.val());
+        blendBlobs[x].secondy = xlate(secondYear.val());
+      }
+#endif
+    }
+    drawLevels (val, y, xlate(0), station->isCurrent
+#ifdef blendingTest
+		, blendBlobs
+#endif
+    );
   }
-  stopPixelCache();
 
   // Draw depth lines later?
   if (tl != 'n')
@@ -553,9 +479,9 @@ void Graph::drawTides (Station *station,
     Dstr dlabel;
     makeDepthLabel (depth, lineStep, unitsDesc, dlabel);
     double adj = 0.0;
-    if (fontHeight() > 1)
-      adj = (double)(fontHeight()) / 2.0;
-    rightJustifyString (labelRight, xlate(0.1*depth)-adj, dlabel);
+    if (oughtHeight() > 1)
+      adj = oughtHeight() / 2.0 + fontHeight() - oughtHeight();
+    rightJustifyStringS (labelRight, xlate(0.1*depth)-adj, dlabel);
   }
 
   // Relatively straightforward logic to figure the increment for the
@@ -577,13 +503,13 @@ void Graph::drawTides (Station *station,
 
   // Do time axis.
   const Timestamp timeAxisStopTime (endTime + Global::hour * timeStep);
-  loopt = startTime;
+  Timestamp loopt = startTime;
   for (loopt.floorHour(station->timezone);
        loopt < timeAxisStopTime;
        loopt.nextHour(station->timezone)) {
     if (loopt.tmStruct(station->timezone).tm_hour % timeStep == 0) {
-      x = Global::iround ((loopt - startTime) / increment);
-      drawHourTick (x, Colors::foreground);
+      const double x = (loopt - startTime) / increment;
+      drawHourTick (x, Colors::foreground, false);
       Dstr ts;
       loopt.printHour (ts, station->timezone);
       labelHourTick (x, ts);
@@ -596,10 +522,8 @@ void Graph::drawTides (Station *station,
   for (loopt.floorDay(station->timezone);
        loopt < timeAxisStopTime;
        loopt.nextDay(station->timezone)) {
-    x = Global::iround ((loopt - startTime) / increment);
-    drawHourTick (x-1, Colors::foreground);
-    drawHourTick (x, Colors::foreground);
-    drawHourTick (x+1, Colors::foreground);
+    const double x = (loopt - startTime) / increment;
+    drawHourTick (x, Colors::foreground, true);
   }
 
   if (_style == clock) {
@@ -607,39 +531,30 @@ void Graph::drawTides (Station *station,
     // Write current time
     Dstr ts;
     currentTime.printTime (ts, station->timezone);
-    centerStringOnLine (_xSize/2, 0, ts);
+    centerStringOnLineSx (_xSize/2.0, 0, ts);
 
     // Write next max
-    centerStringOnLine (_xSize/2, 1, nextMax.longDescription());
+    centerStringOnLineSx (_xSize/2.0, 1, nextMax.longDescription());
     nextMax.eventTime.printTime (ts, station->timezone);
-    centerStringOnLine (_xSize/2, 2, ts);
+    centerStringOnLineSx (_xSize/2.0, 2, ts);
 
     // Write next min
-    centerStringOnLine (_xSize/2, -3, nextMin.longDescription());
+    centerStringOnLineSx (_xSize/2.0, -3, nextMin.longDescription());
     nextMin.eventTime.printTime (ts, station->timezone);
-    centerStringOnLine (_xSize/2, -2, ts);
+    centerStringOnLineSx (_xSize/2.0, -2, ts);
 
   } else {
 
     drawTitleLine (station->name);
 
     // Put timestamps for timestampable events.
-#ifdef DumbTideClockDemo
-    Timestamp firstMaxMinTime;
-#endif
     SafeVector<EventBlurb> topBlurbs, bottomBlurbs;
     EventBlurb tempBlurb;
     for (TideEventsIterator it = organizer.begin();
          it != organizer.end();
          ++it) {
       TideEvent &te = it->second;
-#ifdef DumbTideClockDemo
-      if (firstMaxMinTime.isNull() &&
-          te.eventTime >= startTime &&
-          te.isMaxMinEvent())
-        firstMaxMinTime = te.eventTime;
-#endif
-      tempBlurb.x = Global::iround ((te.eventTime - startTime) / increment);
+      tempBlurb.x = (te.eventTime - startTime) / increment;
       switch (te.eventType) {
       case TideEvent::max:
       case TideEvent::min:
@@ -658,7 +573,7 @@ void Graph::drawTides (Station *station,
       case TideEvent::firstquarter:
       case TideEvent::fullmoon:
       case TideEvent::lastquarter:
-        drawHourTick (tempBlurb.x, Colors::mark);
+        drawHourTick (tempBlurb.x, Colors::mark, false);
 	te.eventTime.printTime (tempBlurb.line2, station->timezone);
         tempBlurb.line1 = te.longDescription();
         if (!isBanner())
@@ -674,57 +589,27 @@ void Graph::drawTides (Station *station,
 
     drawBlurbs (1, topBlurbs);
     drawBlurbs (-3, bottomBlurbs);
-
-#ifdef DumbTideClockDemo
-    if (!firstMaxMinTime.isNull()) {
-      for (loopt = firstMaxMinTime;
-	   loopt < endTime;
-	   loopt += Global::halfCycle) {
-	x = (int) round ((loopt - startTime) / increment);
-	drawVerticalLine (x, (int)_ySize-1, 0, Colors::msl);
-      }
-    }
-#endif
   }
 
   // Extra lines.
   if (!station->markLevel.isNull()) {
-    ytide = xlate(station->markLevel.val());
-    drawHorizontalLine (labelWidth, _xSize-1, ytide, Colors::mark);
+    const double ytide = xlate(station->markLevel.val());
+    drawHorizontalLinePxSy (labelWidth, _xSize-1, ytide, Colors::mark);
   }
-  if (el != 'n') {
-    drawHorizontalLine (labelWidth, _xSize-1, yzulu, Colors::datum);
-    ytide = (ymax + ymin) / 2.0;
-    drawHorizontalLine (labelWidth, _xSize-1, ytide, Colors::msl);
+  if (Global::settings["el"].c != 'n') {
+    drawHorizontalLinePxSy (labelWidth, _xSize-1, xlate(0), Colors::datum);
+    const double ytide = (ymax + ymin) / 2.0;
+    drawHorizontalLinePxSy (labelWidth, _xSize-1, ytide, Colors::msl);
   }
 
   // X marks the current time.
   if (currentTime >= startTime && currentTime < endTime) {
-    x = Global::iround ((currentTime - startTime) / increment);
-    ytide = xlate(station->predictTideLevel(currentTime).val());
-    drawX (x, ytide);
+    const double ytide = xlate(station->predictTideLevel(currentTime).val());
+    drawX ((currentTime - startTime) / increment, ytide);
   }
 }
 
 
-void Graph::drawHorizontalLine (int xlo,
-                                int xhi,
-                                double y,
-				Colors::Colorchoice c) {
-  drawHorizontalLine (xlo, xhi, Global::iround(y), c);
-}
-
-
-void Graph::drawString (int x, double y, const Dstr &s) {
-  drawString (x, Global::iround(y), s);
-}
-
-
-void Graph::centerString (int x, int y, const Dstr &s) {
-  drawString (x-(int)stringWidth(s)/2, y, s);
-}
-
-
 // This must agree with whatever centerString does about odd numbers.
 // However, it doesn't hurt to fudge by an even number to create a
 // margin on both sides.
@@ -741,23 +626,13 @@ const int Graph::blurbMargin() const {
 }
 
 
-void Graph::rightJustifyString (int x, double y, const Dstr &s) {
-  drawString (x-(int)stringWidth(s), y, s);
-}
-
-
-void Graph::centerStringOnLine (int x, int line, const Dstr &s) {
+void Graph::centerStringOnLineSx (double x, int line, const Dstr &s) {
   int y;
   if (line >= 0)
-    y = line * (fontHeight()+fontVerticalMargin());
+    y = line * fontHeight();
   else
-    y = _ySize+(fontHeight()+fontVerticalMargin())*line-hourTickLen();
-  centerString (x, y, s);
-}
-
-
-const unsigned Graph::fontVerticalMargin() const {
-  return 0;
+    y = _ySize+fontHeight()*line-hourTickLen()-hourTickVerticalMargin();
+  centerStringSxPy (x, y, s);
 }
 
 
@@ -781,6 +656,11 @@ const unsigned Graph::hourTickLen() const {
 }
 
 
+const unsigned Graph::hourTickVerticalMargin() const {
+  return 2;
+}
+
+
 const double Graph::aspectFudgeFactor() const {
   return 1.0;
 }
@@ -791,89 +671,28 @@ const unsigned Graph::startPosition (unsigned labelWidth) const {
 }
 
 
-void Graph::setPixel (int x,
-                      int y,
-                      Colors::Colorchoice c,
-		      double saturation) {
-  assert (c < (int)Colors::numColors);
-  if (saturation >= 0.5)
-    setPixel (x, y, c);
+void Graph::drawHourTick (double x, Colors::Colorchoice c, bool thick) {
+  if (thick)
+    drawBoxS (x-1.5, x+1.5, _ySize, _ySize-hourTickLen(), c);
+  else
+    drawVerticalLineS (x, _ySize, _ySize-hourTickLen(), c);
 }
 
 
-void Graph::drawHourTick (int x, Colors::Colorchoice c) {
-  drawVerticalLine (x, (int)_ySize-1, (int)_ySize-hourTickLen(), c);
-}
-
-
-void Graph::drawVerticalLine (int x, int y1, int y2, Colors::Colorchoice c) {
-  int ylo, yhi;
-  if (y1 < y2) {
-    ylo = y1; yhi = y2;
-  } else {
-    ylo = y2; yhi = y1;
-  }
-  for (int i=ylo; i<=yhi; ++i)
-    setPixel (x, i, c);
-}
-
-
-void Graph::drawVerticalLine (int x,
-                              double y1,
-                              double y2,
-                              Colors::Colorchoice c) {
-  double ylo, yhi;
-  if (y1 < y2) {
-    ylo = y1; yhi = y2;
-  } else {
-    ylo = y2; yhi = y1;
-  }
-  int ylo2 ((int) ceil (ylo));
-  int yhi2 ((int) floor (yhi));
-  if (ylo2 < yhi2)
-    drawVerticalLine (x, ylo2, yhi2-1, c);
-  // What if they both fall within the same pixel:  ylo2 > yhi2
-  if (ylo2 > yhi2) {
-    assert (yhi2 == ylo2 - 1);
-    double saturation (yhi - ylo);
-    setPixel (x, yhi2, c, saturation);
-  } else {
-    // The normal case.
-    if (ylo < (double)ylo2) {
-      double saturation ((double)ylo2 - ylo);
-      setPixel (x, ylo2-1, c, saturation);
-    }
-    if (yhi > (double)yhi2) {
-      double saturation (yhi - (double)yhi2);
-      setPixel (x, yhi2, c, saturation);
-    }
-  }
-}
-
-
-void Graph::drawHorizontalLine (int xlo,
-                                int xhi,
-                                int y,
-			        Colors::Colorchoice c) {
-  for (int i=xlo; i<=xhi; ++i)
-    setPixel (i, y, c);
-}
-
-
-void Graph::labelHourTick (int x, const Dstr &label) {
-  centerStringOnLine (x, -1, label);
+void Graph::labelHourTick (double x, const Dstr &label) {
+  centerStringOnLineSx (x, -1, label);
 }
 
 
 void Graph::drawTitleLine (const Dstr &title) {
-  centerStringOnLine (_xSize/2, 0, title);
+  centerStringOnLineSx (_xSize/2.0, 0, title);
 }
 
 
 void Graph::labelEvent (int topLine, const EventBlurb &blurb) {
   // This needs to get overridden in Banner.
-  centerStringOnLine (blurb.x, topLine, blurb.line1);
-  centerStringOnLine (blurb.x, topLine+1, blurb.line2);
+  centerStringOnLineSx (blurb.x, topLine, blurb.line1);
+  centerStringOnLineSx (blurb.x, topLine+1, blurb.line2);
 }
 
 
@@ -882,11 +701,4 @@ const bool Graph::isBanner() const {
 }
 
 
-void Graph::startPixelCache() {
-}
-
-
-void Graph::stopPixelCache() {
-}
-
 // Cleanup2006 LongMethod(drawTides) Done
