@@ -1,4 +1,4 @@
-// $Id: RGBGraph.cc 3700 2010-07-01 00:04:07Z flaterco $
+// $Id: RGBGraph.cc 4303 2012-02-14 00:59:27Z flaterco $
 
 /*  RGBGraph  Graph implemented as raw RGB image.
 
@@ -19,13 +19,13 @@
 */
 
 #include "common.hh"
-#include "glyphs.hh"
 #include "Graph.hh"
+#include "PixelatedGraph.hh"
 #include "RGBGraph.hh"
 
 
 RGBGraph::RGBGraph (unsigned xSize, unsigned ySize, GraphStyle style):
-  Graph (xSize, ySize, style) {
+  PixelatedGraph (xSize, ySize, style) {
   assert (xSize >= Global::minGraphWidth && ySize >= Global::minGraphHeight);
   rgb.resize (xSize * ySize * 3);
   for (unsigned a=0; a<Colors::numColors; ++a)
@@ -36,13 +36,23 @@ RGBGraph::RGBGraph (unsigned xSize, unsigned ySize, GraphStyle style):
 }
 
 
-const unsigned RGBGraph::stringWidth (const Dstr &s) const { 
-  return glyphWidth * s.length();
+const unsigned RGBGraph::stringWidth (const Dstr &s) const {
+  return ::stringWidth (Global::graphFont, s);
 }
 
 
 const unsigned RGBGraph::fontHeight() const {
-  return glyphHeight;
+  return Global::graphFont.height;
+}
+
+
+const unsigned RGBGraph::oughtHeight() const {
+  return Global::graphFont.oughtHeight;
+}
+
+
+const unsigned RGBGraph::oughtVerticalMargin() const {
+  return 1;
 }
 
 
@@ -60,37 +70,33 @@ void RGBGraph::setPixel (int x, int y, Colors::Colorchoice c) {
 void RGBGraph::setPixel (int x,
                          int y,
                          Colors::Colorchoice c,
-                         double saturation) {
+                         double opacity) {
   assert (c < (int)Colors::numColors);
   if (x < 0 || x >= (int)_xSize || y < 0 || y >= (int)_ySize)
     return;
   SafeVector<unsigned char>::iterator it = rgb.begin() + (y * _xSize + x) * 3;
-  *it = linterp (*it, cmap[c][0], saturation);
+  *it = linterp (*it, cmap[c][0], opacity);
   ++it;
-  *it = linterp (*it, cmap[c][1], saturation);
+  *it = linterp (*it, cmap[c][1], opacity);
   ++it;
-  *it = linterp (*it, cmap[c][2], saturation);
+  *it = linterp (*it, cmap[c][2], opacity);
 }
 
 
-void RGBGraph::drawString (int x, int y, const Dstr &s) {
+void RGBGraph::drawStringP (int x, int y, const Dstr &s) {
   for (unsigned a=0; a<s.length(); ++a) {
-    int base = s[a];
-    if (base < 0)
-      base += 256;
-    assert (base >= 0 && base < 256);
-    base *= glyphWidth;
-    for (unsigned int yl=0; yl<fontHeight(); ++yl)
-      for (unsigned int xl=0; xl<glyphWidth; ++xl)
-        if (glyphs[yl][base+xl])
-	  setPixel (x+xl, y+yl, Colors::foreground);
-    x += glyphWidth;
+    const ClientSide::Glyph &g (Global::graphFont.glyphs[(uint8_t)s[a]]);
+    for (SafeVector<ClientSide::Pixel>::const_iterator it (g.pixels.begin());
+	 it != g.pixels.end(); ++it)
+      setPixel (x+it->x, y+it->y, Colors::foreground, it->opacity / 255.0);
+    x += g.advance;
   }
 }
 
 
 // This is a hacked-down version of write_png in example.c in libpng-0.99c.
 // 2010-06-30 Updated deprecated jmpbuf usage.
+// 2011-07-30 Turned off interlacing.
 void RGBGraph::writeAsPNG (png_rw_ptr write_data_fn) {
 
   png_structp png_ptr;
@@ -142,7 +148,7 @@ void RGBGraph::writeAsPNG (png_rw_ptr write_data_fn) {
    * currently be PNG_COMPRESSION_TYPE_BASE and PNG_FILTER_TYPE_BASE. REQUIRED
    */
   png_set_IHDR(png_ptr, info_ptr, _xSize, _ySize, 8, PNG_COLOR_TYPE_RGB,
-     PNG_INTERLACE_ADAM7, PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+     PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
 
   /* Write the file header information.  REQUIRED */
   png_write_info(png_ptr, info_ptr);
