@@ -1,4 +1,4 @@
-/* $Id: Settings.cc 4319 2012-02-16 01:31:47Z flaterco $ */
+/* $Id: Settings.cc 5059 2013-07-21 12:41:26Z flaterco $ */
 
 /*  Settings  XTide global settings
 
@@ -746,6 +746,7 @@ Settings::Settings () {
     {"gh", "gheight", "Initial height for tide graphs (pixels):", Configurable::settingKind, Configurable::unsignedRep, Configurable::posIntInterp, false, std::max(Global::minGraphHeight,defgheight),0,0,Dstr(),PredictionValue(),DstrVector(), Global::minGraphHeight},
     {"tw", "ttywidth", "Width of ASCII graphs, clocks, banners, and calendars (characters):", Configurable::settingKind, Configurable::unsignedRep, Configurable::posIntInterp, false, std::max(Global::minTTYwidth,defttywidth),0,0,Dstr(),PredictionValue(),DstrVector(), Global::minTTYwidth},
     {"th", "ttyheight", "Height of ASCII graphs and clocks (characters):", Configurable::settingKind, Configurable::unsignedRep, Configurable::posIntInterp, false, std::max(Global::minTTYheight,defttyheight),0,0,Dstr(),PredictionValue(),DstrVector(), Global::minTTYheight},
+    {"pi", "predictinterval", "Default predict interval (days):", Configurable::settingKind, Configurable::unsignedRep, Configurable::posIntInterp, false, 4,0,0,Dstr(),PredictionValue(),DstrVector(), 1},
     {"ga", "gaspect", "Initial aspect for tide graphs.", Configurable::settingKind, Configurable::doubleRep, Configurable::posDoubleInterp, false, 0,defgaspect,0,Dstr(),PredictionValue(),DstrVector(), 0},
     {"lw", "lwidth", "Width of line in graph styles l and s (pixels, pos. real number).", Configurable::settingKind, Configurable::doubleRep, Configurable::posDoubleInterp, false, 0,deflwidth,0,Dstr(),PredictionValue(),DstrVector(), 0},
     {"mf", "monofont", "Monospace font (requires restart):", Configurable::settingKind, Configurable::dstrRep, Configurable::textInterp, false, 0,0,0,defmonofont,PredictionValue(),DstrVector(), 0},
@@ -948,9 +949,7 @@ void Settings::applyCommandLine (int argc, constStringArray argv) {
                          it != commandLineArgs.end();
                          ++it)
     if (it->switchName == "v" && it->arg == "y") {
-      Dstr line;
-      Global::versionString (line);
-      fprintf (stderr, "%s\n", line.aschar());
+      fprintf (stderr, "%s\n", XTideVersionString);
       exit (0);
     }
 
