@@ -1,4 +1,4 @@
-// $Id: Station.cc 4340 2012-02-20 03:31:31Z flaterco $
+// $Id: Station.cc 5057 2013-07-21 01:17:04Z flaterco $
 
 /*  Station  A tide station.
 
@@ -500,7 +500,7 @@ void Station::addSunMoonEvents (Timestamp startTime,
     }
 
     // Add moonrises and moonsets.
-    if (startTime.inRangeForLunarRiseSet() && (!(M && m))) {
+    if (!(M && m)) {
       te.eventTime = startTime;
       Skycal::findNextRiseOrSet (te.eventTime,
                                  coordinates,
@@ -512,8 +512,6 @@ void Station::addSunMoonEvents (Timestamp startTime,
   	  finishTideEvent (te);
 	  organizer.add (te);
         }
-	if (!(te.eventTime.inRangeForLunarRiseSet()))
-	  break;
 	Skycal::findNextRiseOrSet (te.eventTime,
                                    coordinates,
                                    Skycal::lunar,
@@ -691,8 +689,7 @@ void Station::aboutMode (Dstr &text_out,
   }
   if (form == Format::HTML)
     text_out += "</table>\n";
-  if (codeset == "UTF-8")
-    text_out.utf8();
+  Global::finalizeCodeset (text_out, codeset, form);
 }
 
 
@@ -728,9 +725,7 @@ void Station::textBoilerplate (Dstr &text_out, Format::Format form) const {
 VERSION:2.0\r\n\
 PRODID:";
     // ISO 9070 compliance not mandatory.
-    Dstr ver;
-    Global::versionString (ver);
-    text_out += ver;
+    text_out += XTideVersionString;
     text_out += "\r\n\
 CALSCALE:GREGORIAN\r\n\
 METHOD:PUBLISH\r\n";
@@ -793,9 +788,7 @@ METHOD:PUBLISH\r\n";
     if (form == Format::HTML)
       text_out += "</h3>";
     text_out += '\n';
-
-    if (Global::codeset == "UTF-8")
-      text_out.utf8();
+    Global::finalizeCodeset (text_out, Global::codeset, form);
   }
 }
 
