@@ -1,4 +1,4 @@
-// $Id: TTYGraph.cc 4337 2012-02-20 00:57:38Z flaterco $
+// $Id: TTYGraph.cc 5057 2013-07-21 01:17:04Z flaterco $
 
 /*  TTYGraph  Graph implemented on dumb terminal
 
@@ -212,6 +212,8 @@ void TTYGraph::print (Dstr &text_out) {
   }
   if (VT100_mode)
     VT100_postproc (text_out);
+  else
+    Global::finalizeCodeset (text_out, Global::codeset, Format::text);
 }
 
 
