@@ -1,4 +1,4 @@
-// $Id: Timestamp.cc 4406 2012-03-04 14:26:16Z flaterco $
+// $Id: Timestamp.cc 5041 2013-07-10 01:54:08Z flaterco $
 
 // Timestamp:  A point in time.  See also Year, Date, Interval.
 
@@ -195,8 +195,15 @@ const bool Timestamp::zoneinfoIsNotHorriblyObsolete () const {
 
 
 /* Declarations for zoneinfo compatibility hack */
-// This is getting to be really ancient history and maybe should be
-// retired, but you never know.
+
+// This is really ancient history and should be killed with fire, but it is
+// still used by Visual Studio.  The hack is now disabled for everything
+// EXCEPT Visual Studio because it masked time zone breakage in an Android
+// port.
+
+#ifdef _MSC_VER
+#define ALLOW_BROKEN_ZONEINFO
+#endif
 
 /* It's not worth detecting or supporting POSIX because all the platforms
    I know of that support full POSIX with floating day rules do so by
@@ -212,6 +219,8 @@ enum ZoneinfoSupportLevel {NEWZONEINFO=0,
 static ZoneinfoSupportLevel zoneinfoSupportLevel (TZNULL);
 
 
+#ifdef ALLOW_BROKEN_ZONEINFO
+
 /* The following were originally based on tzdata96i.  Since then the
    following churn has occurred:
 
@@ -687,6 +696,8 @@ static constString subs[][4] = {
 /* Terminator */
 {NULL, NULL, NULL, NULL}};
 
+#endif
+
 
 // Unfortunately, time zones are a session default.
 static void installTimeZone (const Dstr &timezone) {
@@ -723,7 +734,7 @@ static void installTimeZone (const Dstr &timezone) {
     if (junk[0] == 'E') {
       zoneinfoSupportLevel = NEWZONEINFO;
     } else {
-
+#ifdef ALLOW_BROKEN_ZONEINFO
       Global::log ("\
 XTide Warning:  Using obsolete time zone database.  Summer Time (Daylight\n\
 Savings Time) adjustments will not be done for some locations.", LOG_WARNING);
@@ -744,9 +755,13 @@ Savings Time) adjustments will not be done for some locations.", LOG_WARNING);
 	zoneinfoSupportLevel = BRAINDEAD;
 #endif
       }
+#else
+      Global::barf (Error::BROKEN_ZONEINFO);
+#endif
     }
   }
 
+#ifdef ALLOW_BROKEN_ZONEINFO
   assert (zoneinfoSupportLevel != TZNULL);
 
   /* If our level of support is less than NEWZONEINFO, find the
@@ -760,6 +775,9 @@ Savings Time) adjustments will not be done for some locations.", LOG_WARNING);
 
   // If not found, soldier on with the original value.  The user might
   // know more than we do about what works.
+#else
+  assert (zoneinfoSupportLevel == NEWZONEINFO);
+#endif
 
   /* According to the SYSV man page, I can't alter env_string ever again. */
   sprintf (env_string, "TZ=%s", timezoneLocalVar.aschar());
@@ -1406,11 +1424,4 @@ const time_t Timestamp::timet() const {
 }
 
 
-// The moonrise and moonset logic blows up if you go before 1900 or
-// after 2099.  This is just a range check for that.
-const bool Timestamp::inRangeForLunarRiseSet() const {
-  double skycalYear = 1900. + (jd() - 2415019.5) / 365.25;
-  return (skycalYear > 1900.1 && skycalYear < 2099.9);
-}
-
 // Cleanup2006 Cruft BlamePosix
