@@ -1,4 +1,4 @@
-// $Id: xtide.cc 4327 2012-02-18 22:55:54Z flaterco $
+// $Id: xtide.cc 5040 2013-07-10 01:38:13Z flaterco $
 
 /*  XTide  Harmonic tide clock and tide predictor.
 
@@ -23,6 +23,10 @@
 
 int main (int argc, char **argv) {
   srand (time (NULL));
+  // This should never be used (Visual Studio 2012 can't build xtide).
+  #ifdef NO_INITIALIZER_LISTS
+  Global::initializeGraphFont();
+  #endif
   Global::initTerm();
   Global::root = new xxRoot (argc, argv);
   Global::root->run();
