@@ -1,4 +1,4 @@
-// $Id: xttpd.cc 4359 2012-02-22 03:10:35Z flaterco $
+// $Id: xttpd.cc 5059 2013-07-21 12:41:26Z flaterco $
 
 /*  xttpd  XTide web server.
 
@@ -337,9 +337,7 @@ of every location supported by this server.&nbsp; The master index could be\n\
 very large, so if you are on a slow connection, don't use it.</p>\n";
 
   rootPageText += "<p>Version info:<br>";
-  Dstr vstring;
-  Global::versionString (vstring);
-  rootPageText += vstring;
+  rootPageText += XTideVersionString;
   Dstr hfileIDs;
   Global::stationIndex().hfileIDs (hfileIDs);
   if (!(hfileIDs.isNull())) {
@@ -568,9 +566,10 @@ for some locations. </p>\n";
 
   pageText += "<p><pre>\n";
 
+  Configurable &picfg = Global::settings["pi"];
   station->plainMode (text_out,
                       startTime,
-                      startTime + Global::defaultPredictInterval,
+                      startTime + Interval(picfg.u*DAYSECONDS),
                       Format::text);
   pageText += text_out;
   pageText += "</pre></p>\n";
@@ -1194,6 +1193,11 @@ int main (int argc, char **argv) {
   // Ignore the locale and serve all web pages in ISO 8859-1.
   Global::codeset = "ISO-8859-1";
 
+  // This should never be used (Visual Studio 2012 can't build xttpd).
+  #ifdef NO_INITIALIZER_LISTS
+  Global::initializeGraphFont();
+  #endif
+
   // Build the indices.
   zoneIndex.add (Global::stationIndex());
   // Avoid issuing the zoneinfo warning a million times.
