@@ -1,4 +1,4 @@
-// $Id: xxLocationList.cc 2641 2007-09-02 21:31:02Z flaterco $
+// $Id: xxLocationList.cc 4501 2012-05-27 17:41:58Z flaterco $
 
 /*  xxLocationList   Scrolling location chooser.
 
@@ -20,17 +20,11 @@
 
 #include "xtide.hh"
 #include "xxMultiChoice.hh"
+#include "xxReconfigurable.hh"
 #include "xxLocationList.hh"
 
 
-// This looks configurable, but it isn't.  List windows can't exceed
-// 2^15 pixels in height.  The correct values follow from the font,
-// which also is not configurable, for good reason.
-static const unsigned maxLocListLength  (2000U);
-
-// Correct width depends on the font too.  Height, not so much.
-static const unsigned LocListViewportWidth  (750U);
-static const unsigned LocListViewportHeight (100U);
+static const unsigned locListViewportInitialHeight (200U);
 
 
 static void continuationButtonCallback (Widget w,
@@ -94,12 +88,6 @@ void xxLocationList::pickStation (const XawListReturnStruct *xrs) {
 
 void xxLocationList::listChanged() {
   XawListChange (list->widget(), stringList, 0, 0, 1);
-  // Undo some damage
-  Arg listArgs[2] =  {
-    {XtNwidth,  (XtArgVal)LocListViewportWidth},
-    {XtNheight, (XtArgVal)LocListViewportHeight}
-  };
-  XtSetValues (viewport->widget(), listArgs, 2);
 }
 
 
@@ -124,10 +112,17 @@ void xxLocationList::doContinuationButtons() {
     numContButtons = 0;
 
   if (numContButtons) {
+    Widget westWidget = helpButton->widget();
     for (unsigned b=0; b<numContButtons; ++b) {
-      Arg buttonArgs[2] =  {
+      Arg buttonArgs[8] =  {
         {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
-        {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
+        {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
+	{(char*)XtNfromHoriz, (XtArgVal)westWidget},
+	{(char*)XtNfromVert, (XtArgVal)viewport->widget()},
+	{(char*)XtNleft, (XtArgVal)XawChainLeft},
+	{(char*)XtNright, (XtArgVal)XawChainLeft},
+	{(char*)XtNtop, (XtArgVal)XawChainBottom},
+	{(char*)XtNbottom, (XtArgVal)XawChainBottom}
       };
       char tbuf[80];
       unsigned long last = (b+1)*maxLocListLength-1;
@@ -157,17 +152,18 @@ void xxLocationList::doContinuationButtons() {
       default:
         assert (false);
       }
-      Widget buttonWidget = XtCreateManagedWidget (tbuf,
-        commandWidgetClass, container->widget(), buttonArgs, 2);
+      Widget buttonWidget = xxX::createXtWidget (tbuf,
+        commandWidgetClass, container->widget(), buttonArgs, 8);
       XtAddCallback (buttonWidget, XtNcallback, continuationButtonCallback,
        (XtPointer)this);
       continuationButtons.push_back (new xxWidget (buttonWidget));
+      westWidget = buttonWidget;
     }
   }
 }
 
 
-void xxLocationList::sortKey() {
+void xxLocationList::reconfigure() {
   switch (sortChoice->choice()) {
   case 0:
     _sortKey = StationIndex::sortByName;
@@ -189,38 +185,47 @@ void xxLocationList::sortKey() {
 xxLocationList::xxLocationList (const xxWidget &parent,
 				StationIndex *stationIndex,
                                 xxWindow *globeOrMap):
-  xxWindow (parent, boxContainer),
+  xxWindow (parent, formContainer),
   _globeOrMap(globeOrMap),
   _stationIndex(stationIndex),
   startAt(0),
   _sortKey(StationIndex::sortByName) {
 
   setTitle ("Location List");
-  stringList = _stationIndex->makeStringList(startAt, maxLocListLength);
 
-  Arg labelArgs[3] =  {
+  Arg labelArgs[8] =  {
     {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
     {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
-    {XtNfont, (XtArgVal)xxX::smallFontStruct}
+    {(char*)XtNleft, (XtArgVal)XawChainLeft},
+    {(char*)XtNright, (XtArgVal)XawChainLeft},
+    {(char*)XtNtop, (XtArgVal)XawChainTop},
+    {(char*)XtNbottom, (XtArgVal)XawChainTop},
+    {XtNjustify, (XtArgVal)XtJustifyRight},
+    {fontArgName, xxX::monoFontArgValue}
   };
-  Widget labelWidget = XtCreateManagedWidget (
-"  Location Name                                                           \
+  Widget labelWidget = xxX::createXtWidget (
+"Location Name                                                           \
          Type Latitude Longitude",
-    labelWidgetClass, container->widget(), labelArgs, 3);
+    labelWidgetClass, container->widget(), labelArgs, 8);
   label = xxX::wrap (labelWidget);
 
-  Arg vpArgs[6] =  {
+  Arg vpArgs[10] =  {
+    {XtNheight, (XtArgVal)locListViewportInitialHeight},
+    {(char*)XtNfromVert, (XtArgVal)labelWidget},
     {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
     {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
     {XtNallowVert, (XtArgVal)1},
-    {XtNheight, (XtArgVal)LocListViewportHeight},
-    {XtNwidth,  (XtArgVal)LocListViewportWidth},
-    {XtNforceBars, (XtArgVal)1}
+    {XtNforceBars, (XtArgVal)1},
+    {(char*)XtNleft, (XtArgVal)XawChainLeft},
+    {(char*)XtNright, (XtArgVal)XawChainRight},
+    {(char*)XtNtop, (XtArgVal)XawChainTop},
+    {(char*)XtNbottom, (XtArgVal)XawChainBottom}
   };
 
-  Widget viewportWidget = XtCreateManagedWidget ("", viewportWidgetClass,
-    container->widget(), vpArgs, 6);
+  Widget viewportWidget = xxX::createXtWidget ("", viewportWidgetClass,
+    container->widget(), vpArgs, 10);
   viewport = xxX::wrap (viewportWidget);
+  xxX::fixBorder (viewportWidget);
 
   require (scrollbarWidget = XtNameToWidget (viewportWidget, "vertical"));
   Arg sbArgs[2] = {
@@ -228,39 +233,78 @@ xxLocationList::xxLocationList (const xxWidget &parent,
     {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
   };
   XtSetValues (scrollbarWidget, sbArgs, 2);
+  setRudeness (scrollbarWidget);
 
-  Arg listArgs[7] = {
+  // Fix viewport width and align label with viewport text.
+  Dimension labelWidth=0, scrollbarWidth=0, shadowWidth=0;
+  XtVaGetValues (labelWidget, XtNwidth, (XtArgVal)(&labelWidth), NULL);
+  XtVaGetValues (scrollbarWidget, XtNwidth, (XtArgVal)(&scrollbarWidth),
+#ifdef HAVE_XAW3D
+		 XtNshadowWidth, (XtArgVal)(&shadowWidth),
+#endif
+		 NULL);
+  const Dimension correctWidth (labelWidth+scrollbarWidth+4*shadowWidth);
+  XtVaSetValues (viewportWidget, XtNwidth, (XtArgVal)correctWidth, NULL);
+  XtVaSetValues (labelWidget, XtNwidth, (XtArgVal)(correctWidth-shadowWidth), NULL);
+
+  Arg listArgs[6] = {
     {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
     {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
-    {XtNfont, (XtArgVal)xxX::smallFontStruct},
-    {XtNverticalList, (XtArgVal)1},
-    {XtNdefaultColumns, (XtArgVal)1},
-    {XtNforceColumns, (XtArgVal)1},
-    {XtNlist, (XtArgVal)stringList}
+    {(char*)XtNverticalList, (XtArgVal)1},
+    {(char*)XtNdefaultColumns, (XtArgVal)1},
+    {(char*)XtNforceColumns, (XtArgVal)1},
+    {fontArgName, xxX::monoFontArgValue}
   };
-
-  Widget listWidget = XtCreateManagedWidget ("", listWidgetClass,
-    viewport->widget(), listArgs, 7);
+  Widget listWidget = xxX::createXtWidget ("", listWidgetClass,
+    viewport->widget(), listArgs, 6);
   list = xxX::wrap (listWidget);
   XtAddCallback (listWidget, XtNcallback, xxLocationListChoiceCallback,
     (XtPointer)this);
 
-  Arg buttonArgs[2] =  {
-    {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
-    {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
-  };
+  // It's a pain to install the list after the fact, but we need these params
+  // to know what the correct length should be.  Assume shadowWidth same
+  // on all widgets.
+  Dimension internalHeight=2, rowSpacing=2;
+  XtVaGetValues (listWidget, XtNinternalHeight, (XtArgVal)(&internalHeight),
+		 XtNrowSpacing, (XtArgVal)(&rowSpacing), NULL);
+  maxLocListLength = (32765U - 2 * (internalHeight + shadowWidth)) /
+    (xxFontHeight(xxX::monoFontStruct) + rowSpacing);
+  stringList = _stationIndex->makeStringList(startAt, maxLocListLength);
+  listChanged();
 
-  static constString sortChoices[] = {"Sort by Name",
-				      "Sort by Latitude",
-				      "Sort by Longitude",
-				      NULL};
-  sortChoice = std::auto_ptr<xxMultiChoice> (new xxMultiChoice (*container,
-								sortChoices,
-								0,
-								*this));
   {
-    Widget buttonWidget = XtCreateManagedWidget ("?", commandWidgetClass,
-      container->widget(), buttonArgs, 2);
+    static constString sortChoices[] = {"Sort by Name",
+	  			        "Sort by Latitude",
+				        "Sort by Longitude",
+				        NULL};
+    Arg layoutArgs[5] =  {
+      {(char*)XtNfromVert, (XtArgVal)viewportWidget},
+      {(char*)XtNleft, (XtArgVal)XawChainLeft},
+      {(char*)XtNright, (XtArgVal)XawChainLeft},
+      {(char*)XtNtop, (XtArgVal)XawChainBottom},
+      {(char*)XtNbottom, (XtArgVal)XawChainBottom}
+    };
+    sortChoice = std::auto_ptr<xxMultiChoice> (new xxMultiChoice (*container,
+								  sortChoices,
+								  0,
+								  *this,
+								  layoutArgs,
+								  5));
+  }
+
+  {
+    Arg buttonArgs[8] =  {
+      {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
+      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
+      {(char*)XtNfromHoriz, (XtArgVal)sortChoice->widget()},
+      {(char*)XtNfromVert, (XtArgVal)viewportWidget},
+      {(char*)XtNleft, (XtArgVal)XawChainLeft},
+      {(char*)XtNright, (XtArgVal)XawChainLeft},
+      {(char*)XtNtop, (XtArgVal)XawChainBottom},
+      {(char*)XtNbottom, (XtArgVal)XawChainBottom}
+    };
+    Widget buttonWidget = xxX::createXtWidget ("?", commandWidgetClass,
+      container->widget(), buttonArgs, 8);
     XtAddCallback (buttonWidget, XtNcallback, xxLocationListHelpCallback,
       (XtPointer)this);
     helpButton = xxX::wrap (buttonWidget);
@@ -273,7 +317,7 @@ xxLocationList::xxLocationList (const xxWidget &parent,
   obeyMouseWheel (scrollbarWidget);
 
   realize();
-  fixSize();
+  widthNoSmaller();
 }
 
 
