@@ -1,4 +1,4 @@
-// $Id: xxMap.cc 3636 2010-04-06 23:59:23Z flaterco $
+// $Id: xxMap.cc 4497 2012-05-27 00:33:09Z flaterco $
 
 /*  xxMap   Location chooser using Cylindrical Equidistant projection.
 
@@ -36,6 +36,7 @@
 */
 
 #include "xtide.hh"
+#include "xxReconfigurable.hh"
 #include "xxLocationList.hh"
 #include "xxMap.hh"
 
@@ -351,7 +352,7 @@ void xxMap::redrawMap () {
   updatePosition (xLast, yLast);
 
   // Install new pixmap and station list
-  Arg args[1] = {{"bitmap", (XtArgVal)mapPixmap}};
+  Arg args[1] = {{(char*)"bitmap", (XtArgVal)mapPixmap}};
   XtSetValues (picture->widget(), args, 1);
   blastFlag = false;
   if (locationList.get())
@@ -469,7 +470,7 @@ void xxMap::blast (int x, int y) {
   XDrawArc (xxX::display, mapPixmap, xxX::invertGC, xBlast, yBlast,
             rightClickRadius*2, rightClickRadius*2, 0, 360*64);
 
-  Arg args[1] = {{"bitmap", (XtArgVal)mapPixmap}};
+  Arg args[1] = {{(char*)"bitmap", (XtArgVal)mapPixmap}};
   XtSetValues (picture->widget(), args, 1);
 
   // Make a list of all locations within the blast radius.
@@ -700,7 +701,7 @@ void xxMap::mouseButton (const XButtonEvent *xbe) {
 
 
 xxMap::xxMap (const xxWidget &shell):
-  xxWindow (shell, boxContainer),
+  xxWindow (shell, formContainer),
   stationIndex(Global::stationIndex()),
   zoomLevel(0) {
 
@@ -710,13 +711,17 @@ xxMap::xxMap (const xxWidget &shell):
   topPixmap = xxX::makePixmap (x_map_size + 1, y_map_size + 1);
 
   {
-    Arg args[3] = {
-      {XtNbitmap, (XtArgVal)mapPixmap},
+    Arg args[7] = {
+      {(char*)XtNbitmap, (XtArgVal)mapPixmap},
       {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
-      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
+      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
+      {(char*)XtNleft, (XtArgVal)XawChainLeft},
+      {(char*)XtNright, (XtArgVal)XawChainLeft},
+      {(char*)XtNtop, (XtArgVal)XawChainTop},
+      {(char*)XtNbottom, (XtArgVal)XawChainTop}
     };
-    Widget pictureWidget = XtCreateManagedWidget ("", labelWidgetClass,
-        container->widget(), args, 3);
+    Widget pictureWidget = xxX::createXtWidget ("", labelWidgetClass,
+        container->widget(), args, 7);
     picture = xxX::wrap (pictureWidget);
     XtAddEventHandler (pictureWidget, PointerMotionMask, False,
         xxMapPointerMotionEventHandler, (XtPointer) this);
@@ -732,55 +737,60 @@ xxMap::xxMap (const xxWidget &shell):
     XtGetValues (picture->widget(), args, 2);
   }
 
-  Arg buttonArgs[2] = {
+  Arg reusedArgs[8] =  {
     {XtNbackground, (XtArgVal)xxX::pixels[Colors::button]},
-    {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
+    {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]},
+    {(char*)XtNleft, (XtArgVal)XawChainLeft},
+    {(char*)XtNright, (XtArgVal)XawChainLeft},
+    {(char*)XtNtop, (XtArgVal)XawChainBottom},
+    {(char*)XtNbottom, (XtArgVal)XawChainBottom},
+    {(char*)XtNfromVert, (XtArgVal)picture->widget()},
+    {(char*)XtNfromHoriz, (XtArgVal)NULL}
   };
   {
-    Widget buttonWidget = XtCreateManagedWidget ("List All",
-        commandWidgetClass, container->widget(), buttonArgs, 2);
+    Widget buttonWidget = xxX::createXtWidget ("List All",
+        commandWidgetClass, container->widget(), reusedArgs, 7);
     XtAddCallback (buttonWidget, XtNcallback, xxMapListAllCallback,
         (XtPointer)this);
     listAllButton = xxX::wrap (buttonWidget);
+    reusedArgs[7].value = (XtArgVal)buttonWidget;
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("Zoom Out",
-        commandWidgetClass, container->widget(), buttonArgs, 2);
+    Widget buttonWidget = xxX::createXtWidget ("Zoom Out",
+        commandWidgetClass, container->widget(), reusedArgs, 8);
     XtAddCallback (buttonWidget, XtNcallback, xxMapZoomOutCallback,
         (XtPointer)this);
     zoomOutButton = xxX::wrap (buttonWidget);
+    reusedArgs[7].value = (XtArgVal)buttonWidget;
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("Round",
-        commandWidgetClass, container->widget(), buttonArgs, 2);
+    Widget buttonWidget = xxX::createXtWidget ("Round",
+        commandWidgetClass, container->widget(), reusedArgs, 8);
     XtAddCallback (buttonWidget, XtNcallback, xxMapRoundCallback,
         (XtPointer)this);
     roundButton = xxX::wrap (buttonWidget);
+    reusedArgs[7].value = (XtArgVal)buttonWidget;
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("Dismiss",
-        commandWidgetClass, container->widget(), buttonArgs, 2);
+    Widget buttonWidget = xxX::createXtWidget ("Dismiss",
+        commandWidgetClass, container->widget(), reusedArgs, 8);
     XtAddCallback (buttonWidget, XtNcallback, dismissCallback,
         (XtPointer)this);
     dismissButton = xxX::wrap (buttonWidget);
+    reusedArgs[7].value = (XtArgVal)buttonWidget;
   }{
-    Widget buttonWidget = XtCreateManagedWidget ("?", commandWidgetClass,
-        container->widget(), buttonArgs, 2);
+    Widget buttonWidget = xxX::createXtWidget ("?", commandWidgetClass,
+        container->widget(), reusedArgs, 8);
     XtAddCallback (buttonWidget, XtNcallback, xxMapHelpCallback,
         (XtPointer)this);
     helpButton = xxX::wrap (buttonWidget);
+    reusedArgs[7].value = (XtArgVal)buttonWidget;
   }{
-    Arg latargs[2] = {
-      {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
-      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
-    };
-    Widget latitudeLabelWidget = XtCreateManagedWidget ("Lat -00.0000",
-      labelWidgetClass, container->widget(), latargs, 2);
+    reusedArgs[0].value = (XtArgVal)xxX::pixels[Colors::background];
+    Widget latitudeLabelWidget = xxX::createXtWidget ("Lat -00.0000",
+      labelWidgetClass, container->widget(), reusedArgs, 8);
     latitudeLabel = xxX::wrap (latitudeLabelWidget);
+    reusedArgs[7].value = (XtArgVal)latitudeLabelWidget;
   }{
-    Arg lonargs[2] = {
-      {XtNbackground, (XtArgVal)xxX::pixels[Colors::background]},
-      {XtNforeground, (XtArgVal)xxX::pixels[Colors::foreground]}
-    };
-    Widget longitudeLabelWidget = XtCreateManagedWidget ("Lon -000.0000",
-      labelWidgetClass, container->widget(), lonargs, 2);
+    Widget longitudeLabelWidget = xxX::createXtWidget ("Lon -000.0000",
+      labelWidgetClass, container->widget(), reusedArgs, 8);
     longitudeLabel = xxX::wrap (longitudeLabelWidget);
   }
 
