@@ -1,4 +1,4 @@
-// $Id: xxPredictionWindow.cc 4502 2012-05-27 17:46:59Z flaterco $
+// $Id: xxPredictionWindow.cc 5034 2013-07-08 01:58:13Z flaterco $
 
 /*  xxPredictionWindow  Abstract class for all tide-predicting windows.
 
@@ -175,7 +175,7 @@ static void xxPredictionWindowClockCallback (
 }
 
 
-static void xxPredictionWindowAboutCallback (
+static void xxPredictionWindowAboutSCallback (
                                          Widget w unusedParameter,
                                          XtPointer client_data,
                                          XtPointer call_data unusedParameter) {
@@ -185,6 +185,14 @@ static void xxPredictionWindowAboutCallback (
 }
 
 
+static void xxPredictionWindowAboutXCallback (
+                                         Widget w unusedParameter,
+                                         XtPointer client_data unusedParameter,
+                                         XtPointer call_data unusedParameter) {
+  Global::root->newAboutXTide();
+}
+
+
 static void xxPredictionWindowChooserCallback (
                                          Widget w unusedParameter,
                                          XtPointer client_data unusedParameter,
@@ -381,9 +389,15 @@ void xxPredictionWindow::addNormalButtons (Widget northWidget,
   }{
     Widget buttonWidget = xxX::createXtWidget ("About This Station",
       smeBSBObjectClass, optionsMenu->widget(), boxButtonArgs, 4);
-    XtAddCallback (buttonWidget, XtNcallback, xxPredictionWindowAboutCallback,
+    XtAddCallback (buttonWidget, XtNcallback, xxPredictionWindowAboutSCallback,
 		   (XtPointer)this);
-    aboutButton = xxX::wrap (buttonWidget);
+    aboutStationButton = xxX::wrap (buttonWidget);
+  }{
+    Widget buttonWidget = xxX::createXtWidget ("About XTide",
+      smeBSBObjectClass, optionsMenu->widget(), boxButtonArgs, 4);
+    XtAddCallback (buttonWidget, XtNcallback, xxPredictionWindowAboutXCallback,
+		   (XtPointer)this);
+    aboutXTideButton = xxX::wrap (buttonWidget);
   }{
     Widget buttonWidget = xxX::createXtWidget ("New Location Chooser",
       smeBSBObjectClass, optionsMenu->widget(), boxButtonArgs, 4);
@@ -472,8 +486,10 @@ void xxPredictionWindow::globalRedraw() {
   XtSetValues (mediumRareButton->widget(), buttonArgs, 2);
   assert (clockButton.get());
   XtSetValues (clockButton->widget(), buttonArgs, 2);
-  assert (aboutButton.get());
-  XtSetValues (aboutButton->widget(), buttonArgs, 2);
+  assert (aboutStationButton.get());
+  XtSetValues (aboutStationButton->widget(), buttonArgs, 2);
+  assert (aboutXTideButton.get());
+  XtSetValues (aboutXTideButton->widget(), buttonArgs, 2);
   assert (chooserButton.get());
   XtSetValues (chooserButton->widget(), buttonArgs, 2);
   assert (rootButton.get());
