@@ -1,4 +1,4 @@
-// $Id: xxRoot.cc 4501 2012-05-27 17:41:58Z flaterco $
+// $Id: xxRoot.cc 5036 2013-07-08 23:15:35Z flaterco $
 
 /*  xxRoot  XTide "root" window (control panel, top-level logic)
 
@@ -722,7 +722,7 @@ void xxRoot::globalRedraw() {
 
 void xxRoot::run() {
   if (!Global::disclaimerDisabled()) {
-    (void) new xxDisclaimer (*popup);
+    (void) new xxDisclaimer (*popup, true);
     handleXEvents (returnWhenIdle);
   }
 
@@ -922,6 +922,11 @@ xxHelpBox * const xxRoot::newAbout (const Station *station) {
 }
 
 
+void const xxRoot::newAboutXTide () {
+  (void) new xxDisclaimer (*popup, false);
+}
+
+
 void xxRoot::newErrorBox (const Dstr &errmsg, Error::ErrType fatality) {
   static bool snakeBit (false); // Hide double-barfs.
   if (!snakeBit)
