@@ -1,4 +1,4 @@
-// $Id: xxTextMode.cc 4497 2012-05-27 00:33:09Z flaterco $
+// $Id: xxTextMode.cc 5034 2013-07-08 01:58:13Z flaterco $
 
 /*  xxTextMode  Raw/medium/plain modes, in a window.
 
@@ -126,9 +126,13 @@ The options menu supplies the following commands:\n\
   location.\n\
 \n\
   About This Station:  Show station metadata.\n\
+\n\
+  About XTide:  Show XTide version and GPL.\n\
 \n\
   New Location Chooser:  Open new globe and location list windows to allow\n\
-  selecting a new location.";
+  selecting a new location.\n\
+\n\
+  Control Panel:  Advanced XTide configuration.";
   }
   (void) Global::root->newHelpBox (helpstring);
 }
