@@ -1,4 +1,4 @@
-// $Id: xxWindow.cc 2641 2007-09-02 21:31:02Z flaterco $
+// $Id: xxWindow.cc 4497 2012-05-27 00:33:09Z flaterco $
 
 /*  xxWindow  An XTide window.
 
@@ -89,14 +89,14 @@ xxWindow::xxWindow (const xxWidget &parent,
     case noContainer:
       break;
     case boxContainer:
-      container = xxX::wrap (XtCreateManagedWidget ("",
+      container = xxX::wrap (xxX::createXtWidget ("",
 						    boxWidgetClass,
 						    popup->widget(),
 						    args,
 						    2));
       break;
     case formContainer:
-      container = xxX::wrap (XtCreateManagedWidget ("",
+      container = xxX::wrap (xxX::createXtWidget ("",
 						    formWidgetClass,
 						    popup->widget(),
 						    args,
