@@ -1,4 +1,4 @@
-// $Id: xxX.cc 4508 2012-05-28 18:01:34Z flaterco $
+// $Id: xxX.cc 5043 2013-07-10 23:01:53Z flaterco $
 
 /*  xxX  Globals for interfacing with X11.
 
@@ -23,7 +23,11 @@
 #include "icon_48x48_3color.xpm.hh"
 
 #ifdef HAVE_XAW3DXFT
-#include <X11/Xaw3d/Xaw3dXft.h>
+#define  include(define) #define
+#define  define(define)  include(define)
+#include define(XAWPATH/Xaw3dXft.h)
+#undef   define
+#undef   include
 #endif
 
 
@@ -653,7 +657,9 @@ const Widget xxX::connect (int &argc, char **argv) {
 
 
 #if 0
-static void printClientSideFontInitializer (const ClientSide::Font &f) {
+static void printClientSideFontInitializers (const ClientSide::Font &f) {
+  // The good one (C++11 extended initializer lists), with hooks for
+  // the mediocre one (compound literals as GNU C++ extension).
   printf (" {%u,%u,{\n", f.height, f.oughtHeight);
   for (SafeVector<ClientSide::Glyph>::const_iterator git (f.glyphs.begin());
        git != f.glyphs.end(); ++git) {
@@ -667,7 +673,32 @@ static void printClientSideFontInitializer (const ClientSide::Font &f) {
     if (git+1 != f.glyphs.end()) putchar (',');
     putchar ('\n');
   }
-  printf (" }}\n");
+  printf (" }}\n\n");
+
+  // The bad one (runtime construction) for Visual Studio 2012.
+  printf ("  Global::graphFont.glyphs.reserve (256);\n");
+  printf ("  Global::graphFont.height = %u;\n", f.height);
+  printf ("  Global::graphFont.oughtHeight = %u;\n", f.oughtHeight);
+  for (SafeVector<ClientSide::Glyph>::const_iterator git (f.glyphs.begin());
+       git != f.glyphs.end(); ++git) {
+    printf ("  {\n");
+    printf ("    ClientSide::Glyph g;\n");
+    printf ("    g.advance = %u;\n", git->advance);
+    if (!git->pixels.empty()) {
+      printf ("    {\n");
+      printf ("      const ClientSide::Pixel p[] = {");
+      for (SafeVector<ClientSide::Pixel>::const_iterator pit (git->pixels.begin());
+           pit != git->pixels.end(); ++pit) {
+        if (pit != git->pixels.begin()) putchar (',');
+        printf ("{%d,%d,%u}", pit->x, pit->y, pit->opacity);
+      }
+      printf ("};\n");
+      printf ("      g.pixels.assign (p, p+%lu);\n", git->pixels.size());
+      printf ("    }\n");
+    }
+    printf ("    Global::graphFont.glyphs.push_back (g);\n");
+    printf ("  }\n");
+  }
 }
 #endif
 
@@ -746,6 +777,7 @@ void xxX::connectPostSettingsHook (Widget rootWidget) {
     else
       getClientSideFont (graphFontStruct, Global::graphFont);
   }
+  // printClientSideFontInitializers (Global::graphFont);
 }
 
 
